
import rclpy
from rclpy.node import Node
from geometry_msgs.msg import PoseArray, Pose, Point, Quaternion
from std_msgs.msg import Int16, Empty


class CheckExperimentPose(Node):

    def __init__(self):
        super().__init__('check_experiment_pose')
        self.publisher_ = self.create_publisher(PoseArray, 'moveit_interface/task_space_trajectory', 10)
        self.subscriber_ = self.create_subscription(Int16, 'moveit_interface/trigger', self.trigger_callback, 10)
        self.pub_rviz_model = self.create_publisher(Empty, 'moveit_interface/box', 10)
        msg = Empty()
        self.pub_rviz_model.publish(msg)

    def trigger_callback(self, msg):
        data = msg.data
        if data == 1:
            # start
            pose = Pose(position=Point(x=0.5, y=-0.3, z=0.15), orientation=Quaternion(x=1., y=0., z=0., w=0.)),
        elif data == 2:
            # end
            pose = Pose(position=Point(x=0.5, y=0.3, z=0.15), orientation=Quaternion(x=1., y=0., z=0., w=0.)),
        elif data == 3:
            # square 1
            pose = Pose(position=Point(x=0.4, y=0.1, z=0.15), orientation=Quaternion(x=1., y=0., z=0., w=0.)),
        elif data == 4:
            # square 2
            pose = Pose(position=Point(x=0.4, y=-0.1, z=0.15), orientation=Quaternion(x=1., y=0., z=0., w=0.)),
        elif data == 5:
            # square 3
            pose = Pose(position=Point(x=0.6, y=-0.1, z=0.15), orientation=Quaternion(x=1., y=0., z=0., w=0.)),
        elif data == 6:
            # square 4
            pose = Pose(position=Point(x=0.6, y=0.1, z=0.15), orientation=Quaternion(x=1., y=0., z=0., w=0.)),
        else:
            self.get_logger().warn(f'Pose: {data} is not defined!')
            pose = Pose(position=Point(x=0.5, y=-0.3, z=0.15), orientation=Quaternion(x=1., y=0., z=0., w=0.)),

        # Create a PoseArray message
        pose_array = PoseArray()

        pose_array.poses = pose

        # Publish the PoseArray
        self.publisher_.publish(pose_array)
        self.get_logger().info('Published PoseArray to moveit_interface/task_space_trajectory')


def main(args=None):
    rclpy.init(args=args)

    check_experiment_pose_node = CheckExperimentPose()

    rclpy.spin(check_experiment_pose_node)

    check_experiment_pose_node.destroy_node()
    rclpy.shutdown()


if __name__ == '__main__':
    main()
